==> gbox-scrappers-2.0.3.tgz: package/Scrappers/BaseScrapper.js <==
const isSameApiKey = require('../Helpers/IsSameApiKey')
const splitter = ':'
const throw400 = require('../Helpers/Throw400')
const Database = use('Database')
const CallGboxApi = require('../Helpers/CallGboxApi')

class BaseScrapper {
    constructor(name) {
        let [type, id] = name.split(splitter)
        this.type = type
        this.id = id
        this.name = name
    }
    
    async check(...params) {
        return await this.checkEntity(this.tableName, ...params)
    }
    
    async getMediaHashes(ids) {
        let checkIds = ids ? ids : [this.id]
        let medias = await Database.table(this.mediaTableName).whereIn(this.columnName, checkIds)
        return medias.map(media => media.media)
    }
    
    async checkEntity(tableName, apiKey) {
        let sameApiKey = await isSameApiKey(tableName, this.id, apiKey)
        if(!sameApiKey) throw400(`${this.type} with id ${this.id} not found`)
    }
    
    async permissions(ctx) {
        const callGBoxApi = new CallGboxApi(ctx)
        let permissions = []
        try {
            let res = await callGBoxApi.send(this.api, this.route, 'get')
            if(res.read) permissions.push('read')
            if(res.edit) {
                permissions.push('write')
                permissions.push('delete')
            }
        } catch (e) {
            console.error('error calling api', e)
        }
        return {
            permissions,
            environment: this.name
        }
    }
    
    async getEntityName() {
        const entity = await this.getEntity()
        return (entity && entity[this.nameField || 'name']) || ''
    }
    
    async getEntityClassName() {
        return 'Change this in appropriate scrapper'
    }
    
    async getUsers() {
        let dbResponse = await Database.table(this.participantsTableName)
            .where(this.columnName, this.id)
        return dbResponse.map(row => row.user)
    }
    
    async getEntity() {
        let dbResponse = await Database.table(this.tableName)
            .where('id', this.id)
        return dbResponse[0] && dbResponse[0]
    }
    
    get module() {
        return this.api.split('-')[0]
    }
}

module.exports = BaseScrapper

==> gbox-scrappers-2.2.0.tgz: package/Scrappers/BaseScrapper.js <==
const isSameApiKey = require('../Helpers/IsSameApiKey')
const splitter = ':'
const throw400 = require('../Helpers/Throw400')
const Database = use('Database')
const CallGboxApi = require('../Helpers/CallGboxApi')

class BaseScrapper {
    constructor(name) {
        let [type, id] = name.split(splitter)
        this.type = type
        this.id = id
        this.name = name
    }
    
    async check(...params) {
        return await this.checkEntity(this.tableName, ...params)
    }
    
    async getMediaHashes(ids) {
        let checkIds = ids ? ids : [this.id]
        let medias = await Database.table(this.mediaTableName).whereIn(this.columnName, checkIds)
        return medias.map(media => media.media)
    }
    
    async checkEntity(tableName, apiKey) {
        let sameApiKey = await isSameApiKey(tableName, this.id, apiKey)
        if(!sameApiKey) throw400(`${this.type} with id ${this.id} not found`)
    }
    
    async permissions(ctx) {
        const callGBoxApi = new CallGboxApi(ctx)
        let permissions = []
        try {
            let res = await callGBoxApi.send(this.api, this.route, 'get')
            if(res.read) permissions.push('read')
            if(res.edit) {
                permissions.push('write')
                permissions.push('delete')
            }
        } catch (e) {
            console.error('error calling api', e)
        }
        return {
            permissions,
            environment: this.name
        }
    }
    
    async getEntityName() {
        const entity = await this.getEntity()
        return (entity && entity[this.nameField || 'name']) || ''
    }
    
    async getEntityDescription() {
        const entity = await this.getEntity()
        return (entity && entity[this.descriptionField || 'description']) || ''
    }
    
    async getEntityClassName() {
        return 'Change this in appropriate scrapper'
    }
    
    async getUsers() {
        let dbResponse = await Database.table(this.participantsTableName)
            .where(this.columnName, this.id)
        return dbResponse.map(row => row.user)
    }
    
    async getEntity() {
        if(!this.entityLoaded) {
            let dbResponse = await Database.table(this.tableName)
                .where('id', this.id)
            this.entity = dbResponse && dbResponse[0]
            this.entityLoaded = true
        }
        return this.entity
    }
    
    get module() {
        return this.api.split('-')[0]
    }
}

module.exports = BaseScrapper
